@@ -16,9 +16,9 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
-#include <kaboutdata.h>
+#include <KAboutData>
 #include <KCrash>
-#include <kdelibs4configmigrator.h>
+#include <Kdelibs4ConfigMigrator>
 #include <klocalizedstring.h>
 
 #include <QApplication>
@@ -34,6 +34,8 @@ static const char *DESCRIPTION
 
 int main(int argc, char **argv)
 {
+    // Fixes blurry icons with fractional scaling
+    QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
     QApplication app(argc, argv);
 
     Kdelibs4ConfigMigrator migrate(QStringLiteral("kmines"));
